A helper function to retrieve the id of last modified zip file from a specified
Google Drive folder.
Usage
get_last_modified_zip(folder_id)
Arguments
- folder_id
The ID of the googledrive folder to check for the last
modified zip file.
Value
The name of the last modified zip file in the specified folder.
Author
Sander Devisscher, Martijn Bollen
Examples
if (FALSE) { # \dontrun{
get_last_modified_zip(folder_id = "17p2MZt9LIuhIU72u_JjDBbO7D1IPTv7-")
} # }