Close localhost connection
end_localhost_connection.RdA local host connection will remain open unless closed therefor you should
use this function to close it. This function uses get_active_localhost
under the hood to collect a list of active localhost connections on a given
port.