Unzip last modified zip
unzip_last_modified_zip.RdA function to download and unzip the last modified zip file from a specified Google Drive folder.
Usage
unzip_last_modified_zip(folder_id, exdir = tempdir())Arguments
- folder_id
The ID of the googledrive folder to check for the last modified zip file.
- exdir
The directory where the zip file should be extracted. Defaults to
tempdir().